@@ -10,14 +10,14 @@ from SharedData.SharedDataRealTime import SharedDataRealTime
 
 class SharedData:
     
-    def __init__(self, database, mode='rw', sync_frequency_days=0, user='master'):
+    def __init__(self, database, mode='rw', user='master', debug=False):
+        self.debug=debug
         if Logger.log is None:            
             Logger('SharedData')
+        if debug:
+            Logger.log.debug('Initializing SharedData %s,%s,%s ...' % (user,database,mode))
         
-        Logger.log.debug('Initializing SharedData %s,%s,%s ...' % (user,database,mode))
-        
-        self.database = database
-        self.sync_frequency_days = sync_frequency_days
+        self.database = database        
         self.user = user
         
         self.s3read = False
@@ -37,15 +37,7 @@ class SharedData:
             mode = 'r'
         
         self.mode = mode
-                
-        # last download sync datetime
-        self.lastsync = pd.DataFrame([])
-        self.lastsyncfpath = Path(os.environ['DATABASE_FOLDER']) / (user + '/'+ database + '/lastsync.txt')
-        if self.lastsyncfpath.is_file():
-            self.lastsync = pd.read_csv(self.lastsyncfpath)
-            self.lastsync = self.lastsync.set_index('file')
-            self.lastsync['timestamp'] = pd.to_datetime(self.lastsync['timestamp'])
-
+            
         # DATA DICTIONARY
         # SharedDataTimeSeries: data[feeder][period][tag] (date x symbols)
         # SharedDataFrame: data[feeder][period][date] (symbols x tags)
@@ -53,12 +45,6 @@ class SharedData:
 
         # Symbols collections metadata
         self.metadata = {}
-
-        # DATASET        
-        self.dataset_metadata = Metadata('DATASET/' + database,\
-            mode=mode,sync_frequency_days=sync_frequency_days,\
-            user=self.user)
-        self.dataset = self.dataset_metadata.static
         
         Logger.log.debug('Initializing SharedData %s,%s,%s DONE!' % (user,database,mode))
 
@@ -73,8 +59,9 @@ class SharedData:
     def getMetadata(self, collection):
         if not collection in self.metadata.keys():              
             self.metadata[collection] = Metadata(collection,\
-                mode=self.mode,sync_frequency_days=self.sync_frequency_days,\
-                user=self.user)
+                mode=self.mode,\
+                user=self.user,\
+                debug = self.debug)
         return self.metadata[collection]
 
     def getSymbols(self, collection):        
