@@ -21,9 +21,8 @@ class KinesisLogStreamHandler(logging.StreamHandler):
         self.datastream = None
         self.stream_buffer = []
 
-
         try:
-            session = boto3.Session(profile_name=self.user)
+            session = boto3.Session()
             self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
@@ -110,7 +109,7 @@ class KinesisLogStreamConsumer():
         return self.dflogs
     
     def connect(self):                
-        session = boto3.Session(profile_name=self.user)
+        session = boto3.Session()
         self.client = session.client('kinesis')
         self.stream = self.client.describe_stream(StreamName=os.environ['LOG_STREAMNAME'])
         if self.stream and 'StreamDescription' in self.stream:
@@ -170,13 +169,12 @@ class KinesisLogStreamConsumer():
         
 # REAL TIME
 class KinesisStreamProducer():
-    def __init__(self,stream_name, profile_name):
-        self.stream_name = stream_name
-        self.profile_name = profile_name
+    def __init__(self,stream_name):
+        self.stream_name = stream_name        
         self.datastream = None
         self.stream_buffer = []
         try:
-            session = boto3.Session(profile_name=self.profile_name)
+            session = boto3.Session()
             self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
@@ -194,12 +192,14 @@ class KinesisStreamProducer():
         self.stream_buffer = []
 
 class KinesisStreamConsumer():
-    def __init__(self,stream_name, profile_name):
+    def __init__(self,stream_name):
         self.stream_name = stream_name
-        self.profile_name = profile_name    
         self.stream_buffer = []
+        self.get_stream()
 
-        session = boto3.Session(profile_name=self.profile_name)
+    def get_stream(self):
+        print('Initializing stream...')
+        session = boto3.Session()
         self.client = session.client('kinesis')
         self.stream = self.client.describe_stream(StreamName=self.stream_name)
         if self.stream and 'StreamDescription' in self.stream:
@@ -215,13 +215,17 @@ class KinesisStreamConsumer():
                 self.stream['Shards'][i]['ShardIterator'] = shard_iterator['ShardIterator']
         if self.stream['StreamStatus'] != 'ACTIVE':
             raise Exception('Stream status %s' % (self.stream['StreamStatus']))
+        print('Initializing stream DONE!')
                 
     def consume(self):
+        success=False
+
         for i in range(len(self.stream['Shards'])):
             try:
                 response = self.client.get_records(\
                     ShardIterator = self.stream['Shards'][i]['ShardIterator'],\
                     Limit = 100)
+                success = True
                 self.stream['Shards'][i]['ShardIterator'] = response['NextShardIterator']
                 if len(response['Records'])> 0:
                     for r in response['Records']:
@@ -230,8 +234,12 @@ class KinesisStreamConsumer():
                             self.stream_buffer.append(rec)
                         except Exception as e:
                             print('Invalid record:'+str(r['Data']))
-                            print('Invalid record:'+str(e))
+                            print('Invalid record:'+str(e))                
+                
             except Exception as e:
                 print('Kinesis consume exception:%s' % (e))
+                break
+
+        return success
             
      
\ No newline at end of file
