@@ -19,14 +19,16 @@ from SharedData.SharedDataRealTime import SharedDataRealTime
 
 class SharedDataFrame:
 
-    def __init__(self, sharedDataPeriod, tag, df=None):    
+    def __init__(self, sharedDataPeriod, tag, df=None):        
         self.sharedDataPeriod = sharedDataPeriod
         self.tag = tag
         self.tagstr = self.tag.strftime('%Y%m%d%H%M')
         
+        
         self.sharedDataFeeder = sharedDataPeriod.sharedDataFeeder
         self.feeder = sharedDataPeriod.sharedDataFeeder.feeder
         self.sharedData = sharedDataPeriod.sharedDataFeeder.sharedData
+        self.debug = self.sharedData.debug
         self.database = self.sharedData.database
 
         self.period = sharedDataPeriod.period
@@ -42,23 +44,8 @@ class SharedDataFrame:
                 if self.sharedData.s3read:
                     #Synchronize S3                
                     path, shm_name = self.getDataPath()
-
-                    # Sync download S3 files
-                    sync = False
-                    lastsync = self.sharedData.lastsync
-                    if not shm_name in lastsync.index:
-                        sync = True
-                    else:
-                        td = (datetime.utcnow() - lastsync['timestamp'][shm_name]).seconds/86400
-                        if td>self.sharedData.sync_frequency_days:
-                            sync=True
-                                                            
-                    if sync:
-                        if S3SyncDownloadDataFrame(path, shm_name):
-                            lastsync.loc[shm_name,'timestamp'] = datetime.utcnow()
-                            lastsync.index.name = 'file'
-                            lastsync.to_csv(self.sharedData.lastsyncfpath)
-                    
+                    S3SyncDownloadDataFrame(path, shm_name)
+                            
                 # Read
                 df = self.Read()
                 if not df.empty:
@@ -92,8 +79,9 @@ class SharedDataFrame:
     # C R U D
     def Malloc(self, df=None):
         tini=time.time()
-        Logger.log.debug('Malloc %s/%s/%s/%s ...%.2f%% ' % \
-            (self.database,self.feeder,self.period,self.tagstr,0.0))      
+        if self.debug:
+            Logger.log.debug('Malloc %s/%s/%s/%s ...%.2f%% ' % \
+                (self.database,self.feeder,self.period,self.tagstr,0.0))      
 
         #Create write ndarray
         path, shm_name = self.getDataPath()
@@ -124,9 +112,10 @@ class SharedDataFrame:
                         'columns': self.data.columns.values.tolist()                                 
                         }
                     json.dump(shm_info, outfile, indent=3)
+                if self.debug:
+                    Logger.log.debug('Malloc create %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
+                        (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
 
-                Logger.log.debug('Malloc create %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
-                    (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))                
                 return True
             except:
                 trymap=True
@@ -154,9 +143,9 @@ class SharedDataFrame:
                         iidx = df.index.intersection(self.data.index)
                         icol = df.columns.intersection(self.data.columns)
                         self.data.loc[iidx, icol] = df.loc[iidx, icol].copy()
-                                            
-                    Logger.log.debug('Malloc map %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
-                        (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))                    
+                    if self.debug:
+                        Logger.log.debug('Malloc map %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
+                            (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))                    
                     return True
                 except:
                     return False
@@ -170,8 +159,9 @@ class SharedDataFrame:
         npypath = path / (self.tagstr+'.npy')
             
         if (jsonpath.is_file()) & (npypath.is_file()):
-            Logger.log.debug('Reading %s/%s/%s ...%.2f%% ' % \
-                (self.feeder,self.period,self.tagstr,0.0))  
+            if self.debug:
+                Logger.log.debug('Reading %s/%s/%s ...%.2f%% ' % \
+                    (self.feeder,self.period,self.tagstr,0.0))  
             with open(str(jsonpath), 'r') as infile:
                 try:
                     shm_info = json.load(infile)
@@ -185,9 +175,9 @@ class SharedDataFrame:
                     df = pd.DataFrame(values,\
                         index=_index,\
                         columns=_columns)
-
-                    Logger.log.debug('Reading %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
-                        (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
+                    if self.debug:
+                        Logger.log.debug('Reading %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
+                            (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
                     return df
                 except:
                     pass
@@ -197,8 +187,9 @@ class SharedDataFrame:
 
     def Write(self,startDate=None):
         tini = time.time()
-        Logger.log.debug('Writing %s/%s/%s/%s  ...%.2f%% ' % \
-            (self.database,self.feeder,self.period,self.tagstr,0.0))        
+        if self.debug:
+            Logger.log.debug('Writing %s/%s/%s/%s  ...%.2f%% ' % \
+                (self.database,self.feeder,self.period,self.tagstr,0.0))        
 
         path, shm_name = self.getDataPath()
         jsonpath = path / (self.tagstr+'.json')
@@ -218,8 +209,9 @@ class SharedDataFrame:
         if self.sharedData.s3write:
             S3Upload(npypath)
 
-        Logger.log.debug('Writing %s/%s/%s/%s ...%.2f%% %.2f sec!' % \
-            (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
+        if self.debug:
+            Logger.log.debug('Writing %s/%s/%s/%s ...%.2f%% %.2f sec!' % \
+                (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
         
     def Broadcast(self,idx,col):
         SharedDataRealTime.Broadcast(
