@@ -23,7 +23,8 @@ class SharedDataTimeSeries:
         self.tag = tag
         
         self.sharedDataFeeder = sharedDataPeriod.sharedDataFeeder
-        self.sharedData = sharedDataPeriod.sharedDataFeeder.sharedData        
+        self.sharedData = sharedDataPeriod.sharedDataFeeder.sharedData
+        self.debug = self.sharedData.debug
 
         self.period = sharedDataPeriod.period
         self.periodSeconds = sharedDataPeriod.periodSeconds               
@@ -40,10 +41,10 @@ class SharedDataTimeSeries:
             sharedData = sharedDataPeriod.sharedData
         
             if not tag in dataset.index:                
-                if (not sharedDataPeriod.default_startDate is None) \
-                    & (not sharedDataPeriod.default_collections is None):
+                if (not self.sharedDataFeeder.default_collections is None):
                     self.startDate = sharedDataPeriod.default_startDate
-                    self.collections = sharedDataPeriod.default_collections.split(',')
+                    self.collections = self.sharedDataFeeder.default_collections
+                    self.collections = self.collections.replace('\n','').split(',')
                 else:
                     raise ValueError('tag '+tag+' not found in dataset!')
             else:
@@ -70,20 +71,8 @@ class SharedDataTimeSeries:
                 if self.sharedData.s3read:
                     path, shm_name = self.getDataPath()
                     path = str(path)
-                    # Sync download S3 files
-                    lastsync = self.sharedData.lastsync
-                    if not shm_name in lastsync.index:
-                        if S3SyncDownloadTimeSeries(path, shm_name):
-                            lastsync.loc[shm_name,'timestamp'] = datetime.utcnow()
-                            lastsync.index.name = 'file'
-                            lastsync.to_csv(self.sharedData.lastsyncfpath)
-                    else:
-                        td = (datetime.utcnow() - lastsync['timestamp'][shm_name]).seconds/86400
-                        if td>self.sharedData.sync_frequency_days:
-                            if S3SyncDownloadTimeSeries(path, shm_name):
-                                lastsync.loc[shm_name,'timestamp'] = datetime.utcnow()
-                                lastsync.index.name = 'file'
-                                lastsync.to_csv(self.sharedData.lastsyncfpath)
+                    S3SyncDownloadTimeSeries(path, shm_name)
+                                        
                 self.Read()                
         
         else: # map existing dataframe
@@ -100,15 +89,12 @@ class SharedDataTimeSeries:
             isCreate = self.Malloc(value=value)
 
     def getDataPath(self):        
-        shm_name = self.sharedData.user
-        shm_name = shm_name + '/' + self.sharedData.database
-        shm_name = shm_name + '/' + self.sharedDataFeeder.feeder
-        shm_name = shm_name + '/' + self.period + '/' + self.tag
+        shm_name = self.sharedData.user + '\\' + self.sharedData.database + '\\' + self.sharedDataFeeder.feeder + '\\' + self.period + '\\' + self.tag
         shm_name = shm_name.replace('\\','/')
         
         path = Path(os.environ['DATABASE_FOLDER'])
         path = path / shm_name
-        path = Path(str(path).replace('\\','/'))
+        #path = Path(str(path).replace('\\','/'))
         if not os.path.isdir(path):
             os.makedirs(path)
         return path, shm_name
@@ -197,12 +183,13 @@ class SharedDataTimeSeries:
     def Malloc(self, value=None):
         tini=time.time()
         
-
         #Create write ndarray
         path, shm_name = self.getDataPath()
         fpath = path / ('shm_info.json')
+        if self.debug:
+            Logger.log.debug('Malloc %s ...%.2f%% ' % (shm_name,0.0))
 
-        Logger.log.debug('Malloc %s ...%.2f%% ' % (shm_name,0.0))
+        file_exists = False
         try: # try create memory file
             rows = len(self.index)
             cols = len(self.columns)
@@ -234,9 +221,10 @@ class SharedDataTimeSeries:
                     'columns': self.data.columns.values.tolist()                                 
                     }
                 json.dump(shm_info, outfile, indent=3)
-
-            Logger.log.debug('Malloc create %s ...%.2f%% %.2f sec! ' % \
-                (shm_name,100,time.time()-tini))            
+            
+            if self.debug:
+                Logger.log.debug('Malloc create %s ...%.2f%% %.2f sec! ' % \
+                    (shm_name,100,time.time()-tini))            
 
             return True
         except:
@@ -266,8 +254,9 @@ class SharedDataTimeSeries:
                     icol = value.columns.intersection(self.data.columns)
                     self.data.loc[iidx, icol] = value.loc[iidx, icol]
 
-                Logger.log.debug('Malloc map %s/%s/%s ...%.2f%% %.2f sec! ' % \
-                    (self.feeder,self.period,self.tag,100,time.time()-tini))      
+                if self.debug:
+                    Logger.log.debug('Malloc map %s/%s/%s ...%.2f%% %.2f sec! ' % \
+                        (self.feeder,self.period,self.tag,100,time.time()-tini))      
         return False
       
     def Read(self):   
@@ -279,8 +268,9 @@ class SharedDataTimeSeries:
         files = files.sort_values(by='year')
         nfiles = len(files.index)
         if nfiles>0:
-            tini=time.time() 
-            Logger.log.debug('Reading %s ...%.2f%% ' % (shm_name,0.0))   
+            tini=time.time()
+            if self.debug:
+                Logger.log.debug('Reading %s ...%.2f%% ' % (shm_name,0.0))   
             n=0
             for f in files.index:
                 fpath=files.loc[f,'fpath']            
@@ -298,9 +288,9 @@ class SharedDataTimeSeries:
 
                     self.setValuesJit(self.data.values,tidx,sidx,arr[:,1:])
                 n=n+1                
-
-            Logger.log.debug('Reading %s ...%.2f%% %.2f sec! ' % \
-                (shm_name,100*(n/nfiles),time.time()-tini))
+            if self.debug:
+                Logger.log.debug('Reading %s ...%.2f%% %.2f sec! ' % \
+                    (shm_name,100*(n/nfiles),time.time()-tini))
 
     def Write(self, busdays=None, startDate=None):
         tini = time.time()
@@ -319,8 +309,9 @@ class SharedDataTimeSeries:
             os.makedirs(path)        
 
         startdatestr = lastdate.strftime('%Y-%m-%d')
-        Logger.log.debug('Writing %s from %s ...%.2f%% ' % \
-            (shm_name,startdatestr,0.0))
+        if self.debug:
+            Logger.log.debug('Writing %s from %s ...%.2f%% ' % \
+                (shm_name,startdatestr,0.0))
         
             
         years = self.data.loc[lastdate:,:].index.year.unique()
@@ -344,9 +335,9 @@ class SharedDataTimeSeries:
                     S3Upload(fpath_npy)
                     S3Upload(fpath_csv)
                 cy=cy+1      
-
-        Logger.log.debug('Writing %s from %s ...%.2f%% %.2f sec!' % \
-            (shm_name,startdatestr,100*cy/ny,time.time()-tini))        
+        if self.debug:
+            Logger.log.debug('Writing %s from %s ...%.2f%% %.2f sec!' % \
+                (shm_name,startdatestr,100*cy/ny,time.time()-tini))        
             
     def Broadcast(self,idx,col):
         SharedDataRealTime.Broadcast(
